@@ -2,6 +2,7 @@ import sys
 import json
 from os.path import expanduser, isfile
 import locale
+import ap2en
 import click
 import requests
 from collections import OrderedDict
@@ -100,7 +101,10 @@ def cli(ctx, apiroot, config, organization):
 @click.pass_context
 def submit(ctx, file, project, title, test):
     '''Submit your run to the project specified'''
-    project = get_project_id(ctx, project)
+    project = get_project_id(project)
+    if not project:
+        return
+
     with click.open_file(file, 'r') as f:
         try:
             protocol = json.loads(f.read())
@@ -135,7 +139,6 @@ def submit(ctx, file, project, title, test):
 @cli.command()
 @click.argument('package', required=False)
 @click.option('--name', '-n', help="Optional name for your zip file")
-# @click.option('--upload', '-u', help="Upload release to specified package")
 @click.pass_context
 def release(ctx, name=None, package=None):
     '''Compress the contents of the current directory to upload as a release'''
@@ -165,7 +168,7 @@ def release(ctx, name=None, package=None):
     zf.close()
     click.echo("Archive %s created." % (filename + ".zip"))
     if package:
-        package_id = get_package_id(ctx, package) or get_package_name(ctx, package)
+        package_id = get_package_id(package) or get_package_name(package)
         ctx.invoke(upl, archive=(filename + ".zip"), package=package_id)
 
 
@@ -176,10 +179,10 @@ def release(ctx, name=None, package=None):
 def upl(ctx, archive, package):
     """Upload an existing archive to an existing package"""
     try:
-        package_id = get_package_id(ctx, package.lower()) or get_package_name(ctx, package.lower())
+        package_id = get_package_id(package.lower()) or get_package_name(package.lower())
         click.echo("Uploading %s to %s" % (archive,
-                                           (get_package_name(ctx,package_id.lower()) or
-                                            get_package_id(ctx, package_id.lower()))))
+                                           (get_package_name(package_id.lower()) or
+                                            get_package_id(package_id.lower()))))
     except AttributeError:
         click.echo("Error: Invalid package id or name.")
         return
@@ -215,27 +218,27 @@ def upl(ctx, archive, package):
         bar.update(20)
         response_tree = ET.fromstring(response.content)
         loc = dict((i.tag, i.text) for i in response_tree)
-        up = ctx.obj.post('/packages/%s/releases/' % package_id,
-                          data = json.dumps({"release":
-                                             {
-                                              "binary_attachment_url": loc["Key"]
-                                              }
-                                            }),
-                          headers= {
-                            "Origin": "https://secure.transcriptic.com/",
-                            "Content-Type": "application/json"
-                          })
         try:
+            up = ctx.obj.post('/packages/%s/releases/' % package_id,
+                              data = json.dumps({"release":
+                                                 {
+                                                  "binary_attachment_url": loc["Key"]
+                                                  }
+                                                }),
+                              headers= {
+                                "Origin": "https://secure.transcriptic.com/",
+                                "Content-Type": "application/json"
+                              })
             re = json.loads(up.content)['id']
         except ValueError:
-            click.echo("\nError: There was a problem uploading your release. Verify"
+            click.echo("\nError: There was a problem uploading your release. \nVerify"
                        " that your manifest.json file is properly formatted and"
                        " that all previews in your manifest produce valid "
                        "Autoprotocol by using the `transcriptic preview` "
                        "and/or `transcriptic analyze` commands.")
             return
         bar.update(20)
-        time.sleep(20)
+        time.sleep(10)
         status = ctx.obj.get('/packages/%s/releases/%s?_=%s' % (package_id, re,
                                                                 int(time.time())))
         published = json.loads(status.content)['published']
@@ -245,7 +248,7 @@ def upl(ctx, archive, package):
             click.echo("\nPackage upload to %s unsuccessful. "
                        "The following error was "
                        "returned: %s" %
-                       (get_package_name(ctx, package_id),
+                       (get_package_name(package_id),
                         (',').join(e.get('message', '[Unknown]') for
                                    e in errors)))
         else:
@@ -262,7 +265,7 @@ def packages(ctx, i):
     package_names = {}
     if response.status_code == 200:
         for pack in response.json():
-            package_names[str(pack['name']).lower()] = str(pack['id'])
+            package_names[str(pack['name']).lower().replace("com.%s." % ctx.obj.organization, "")] = str(pack['id'])
     if i:
         return package_names
     else:
@@ -288,7 +291,7 @@ def new_package(ctx, description, name):
             return
     new_pack = ctx.obj.post('/packages/',
                             data = json.dumps({"description": description,
-                                               "name": name
+                                               "name": "%s%s" % ("com.%s." % ctx.obj.organization, name)
                                               }))
     if new_pack.status_code == 201:
         click.echo("New package %s created with id %s \n"
@@ -461,6 +464,19 @@ def preview(protocol_name):
         call(["bash", "-c", command + " " + fp.name])
 
 
+@cli.command()
+@click.argument('file', default='-')
+@click.pass_context
+def summarize(ctx, file):
+    with click.open_file(file, 'r') as f:
+        try:
+            protocol = json.loads(f.read())
+        except ValueError:
+            click.echo("The autoprotocol you're trying to summarize is invalid.")
+            return
+    ap2en.AutoprotocolParser(protocol)
+
+
 @cli.command()
 @click.argument('protocol_name')
 @click.argument('args', nargs=-1)
@@ -551,13 +567,14 @@ def login(ctx, api_root):
 @click.pass_context
 def get_project_id(ctx, name):
     projs = ctx.invoke(projects, i=True)
-    id = projs.get(name) or name
-    if id:
-        return id
-    else:
-        click.echo("A project with the name %s was not found in your "
-                   "organization." % name)
-        return
+    id = projs.get(name.lower())
+    if not id:
+        id = name if name in projs.values() else None
+        if not id:
+            click.echo("A project with the name or id '%s' was not found in your "
+                       "organization." % name)
+            return
+    return id
 
 
 @click.pass_context
